package de.intevation.gnv.timeseries.gap;

import java.io.Serializable;

/**
 * A class representing a timegap. <code>TimeGap</code>s are used in timeseries
 * charts to identify gaps taking account for the resolution of the x-axis
 * range.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface TimeGap extends Serializable {

    public final static String TIME_UNIT_MINUTE = "m";
    public final static String TIME_UNIT_HOUR = "h";
    public final static String TIME_UNIT_DAY = "D";
    public final static String TIME_UNIT_WEEK = "W";
    public final static String TIME_UNIT_MONTH = "M";
    public final static String TIME_UNIT_YEAR = "Y";

    public final static long  MINUTE_IN_MILLIS = 60 * 1000;
    public final static long  HOUR_IN_MILLIS = 60 * MINUTE_IN_MILLIS;
    public final static long  DAY_IN_MILLIS = 24 * HOUR_IN_MILLIS;
    public final static long  WEEK_IN_MILLIS = 7 * DAY_IN_MILLIS;


    /**
     * Returns the Lookup-Key for the TimeGap
     *
     * @return the timegap key.
     */
    int getKey();

    /**
     * Returns the Value of the TimeValue in the Unit which is also given.
     *
     * @return the timegap value.
     */
    int getValue();

    /**
     * Returns the Unit of the Timegap (e.g. Minutes, Hours, Days, Weeks, Months, Years)
     *
     * @return the timegap unit.
     */
    String getUnit();

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :